# Generated by Django 3.2.4 on 2021-08-31 05:38

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('logtailer', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='logfile',
            options={'verbose_name': 'Log file', 'verbose_name_plural': 'Log files'},
        ),
        migrations.AlterModelOptions(
            name='logsclipboard',
            options={'verbose_name': 'logs clipboard', 'verbose_name_plural': 'logs clipboard'},
        ),
        migrations.AlterField(
            model_name='logsclipboard',
            name='log_file',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='logtailer.logfile', verbose_name='log file'),
        ),
    ]
