#logfile_form #apply-label {
    margin-left: 5px;
    margin-right: 5px;
}

#logfile_form #apply-filter {
    margin: 0px;
}

#logfile_form #start-button {
    float: left;
}

#logfile_form #stop-button {
    float: left;
}

@media (max-width: 767px){
#logfile_form #apply-filter-row {
    width: 100%;
    padding: 10px 0px 10px 0px;
}}

#log-window-container{
    text-align: center; width: 100%; margin-bottom: 5px;
}

#log-window{
    width: 98%;
    text-align: left;
    background-color: #000;
    color: #ccc;
    font-size: 14px;
    height: 500px;
    overflow: auto;
    padding: 10px;
    line-height: 18px;
    margin: 0 auto;
}

#clipboard-form-container{
    margin: 20px;
    text-align: center;
}

#clipboard-form{
    margin: 0 auto;
    text-align: left;
}

.modal-overlay {
    background: rgba(0, 0, 0, 0.7);
    width: 100%;
    height: 100%;
    position: fixed;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    z-index:99;
}

.modal-wrapper {
    background: var(--body-bg);
    position: fixed;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    border-radius: 25px;
    border: 2px solid var(--hairline-color);
}

.modal-content {
    margin: 20px auto;
    max-width: 210px;
    width: 100%;
}

.hide {
    display: none;
}

h1 {
    text-align: center;
}
