{% load i18n %}
<select name="filters" id="filter-select">
	{%for f in filters%}
		<option value="{{f.regex}}">{{f.name}}</option>
	{%endfor%}
	<option value="custom">{% trans "custom" %}</option>
</select>